@@ -285,8 +285,8 @@
 
 
 ;;;### (autoloads (binhex-decode-region binhex-decode-region-external
-;;;;;;  binhex-decode-region-internal) "binhex" "binhex.el" (15895
-;;;;;;  52374))
+;;;;;;  binhex-decode-region-internal) "binhex" "binhex.el" (15916
+;;;;;;  61430))
 ;;; Generated autoloads from binhex.el
 
 (defconst binhex-begin-line "^:...............................................................$")
@@ -320,10 +320,10 @@ nil instead of to signal an error by setting the option
 ;;;***
 
 ;;;### (autoloads (gnus-article-outlook-deuglify-article gnus-outlook-deuglify-article
-;;;;;;  gnus-outlook-repair-attribution gnus-outlook-unwrap-lines
+;;;;;;  gnus-article-outlook-repair-attribution gnus-article-outlook-unwrap-lines
 ;;;;;;  gnus-outlook-display-hook gnus-outlook-deuglify-unwrap-max
 ;;;;;;  gnus-outlook-deuglify-unwrap-min) "deuglify" "deuglify.el"
-;;;;;;  (15905 32039))
+;;;;;;  (15916 61431))
 ;;; Generated autoloads from deuglify.el
 
 (defvar gnus-outlook-deuglify-unwrap-min 45 "\
@@ -336,20 +336,21 @@ Maximum length of the cited line after unwrapping.")
 A hook called after an deuglified article has been prepared.
 It is run after `gnus-article-prepare-hook'.")
 
-(autoload (quote gnus-outlook-unwrap-lines) "deuglify" "\
+(autoload (quote gnus-article-outlook-unwrap-lines) "deuglify" "\
 Unwrap lines that appear to be wrapped citation lines.  
 You can control what lines will be unwrapped by frobbing
 `gnus-outlook-deuglify-unwrap-min' and `gnus-outlook-deuglify-unwrap-max',
 indicating the miminum and maximum length of an unwrapped citation line.  If
 NODISPLAY is non-nil, don't redisplay the article buffer." t nil)
 
-(autoload (quote gnus-outlook-repair-attribution) "deuglify" "\
+(autoload (quote gnus-article-outlook-repair-attribution) "deuglify" "\
 Repair a broken attribution line.
 If NODISPLAY is non-nil, don't redisplay the article buffer." t nil)
 
 (autoload (quote gnus-outlook-deuglify-article) "deuglify" "\
-Deuglify broken Outlook (Express) articles.
-If NODISPLAY is non-nil, don't redisplay the article buffer." t nil)
+Full deuglify of broken Outlook (Express) articles.
+Treat dumbquotes, unwrap lines, repair attribution and rearrange citation.  If
+NODISPLAY is non-nil, don't redisplay the article buffer." t nil)
 
 (autoload (quote gnus-article-outlook-deuglify-article) "deuglify" "\
 Deuglify broken Outlook (Express) articles and redisplay." t nil)
@@ -366,7 +367,7 @@ Play sounds in message buffers." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus gnus-other-frame gnus-slave gnus-no-server
-;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (15905 32042))
+;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (15916 61435))
 ;;; Generated autoloads from gnus.el
 
 (autoload (quote gnus-slave-no-server) "gnus" "\
@@ -405,7 +406,7 @@ prompt the user for the name of an NNTP server to use." t nil)
 ;;;### (autoloads (gnus-agent-regenerate gnus-agent-batch gnus-agent-batch-fetch
 ;;;;;;  gnus-agent-possibly-save-gcc gnus-agentize gnus-slave-unplugged
 ;;;;;;  gnus-plugged gnus-unplugged) "gnus-agent" "gnus-agent.el"
-;;;;;;  (15905 32040))
+;;;;;;  (15916 61431))
 ;;; Generated autoloads from gnus-agent.el
 
 (autoload (quote gnus-unplugged) "gnus-agent" "\
@@ -444,7 +445,7 @@ If CLEAN, don't read existing active files." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-article-prepare-display) "gnus-art" "gnus-art.el"
-;;;;;;  (15905 64398))
+;;;;;;  (15916 61431))
 ;;; Generated autoloads from gnus-art.el
 
 (autoload (quote gnus-article-prepare-display) "gnus-art" "\
@@ -453,7 +454,7 @@ Make the current buffer look like a nice article." nil nil)
 ;;;***
 
 ;;;### (autoloads (gnus-audio-play) "gnus-audio" "gnus-audio.el"
-;;;;;;  (15418 33141))
+;;;;;;  (15916 61432))
 ;;; Generated autoloads from gnus-audio.el
 
 (autoload (quote gnus-audio-play) "gnus-audio" "\
@@ -606,10 +607,14 @@ Reminder user if there are unsent drafts." t nil)
 
 ;;;### (autoloads (gnus-convert-gray-x-face-region gnus-convert-gray-x-face-to-xpm
 ;;;;;;  gnus-convert-face-to-png gnus-face-from-file gnus-x-face-from-file
-;;;;;;  gnus-random-x-face) "gnus-fun" "gnus-fun.el" (15905 64405))
+;;;;;;  gnus-insert-random-x-face-header gnus-random-x-face) "gnus-fun"
+;;;;;;  "gnus-fun.el" (15916 61432))
 ;;; Generated autoloads from gnus-fun.el
 
 (autoload (quote gnus-random-x-face) "gnus-fun" "\
+Return X-Face header data chosen randomly from `gnus-x-face-directory'." t nil)
+
+(autoload (quote gnus-insert-random-x-face-header) "gnus-fun" "\
 Insert a random X-Face header from `gnus-x-face-directory'." t nil)
 
 (autoload (quote gnus-x-face-from-file) "gnus-fun" "\
@@ -628,7 +633,7 @@ Convert the X-Faces in region to a PPM file." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-fetch-group-other-frame gnus-fetch-group)
-;;;;;;  "gnus-group" "gnus-group.el" (15905 32040))
+;;;;;;  "gnus-group" "gnus-group.el" (15916 61433))
 ;;; Generated autoloads from gnus-group.el
 
 (autoload (quote gnus-fetch-group) "gnus-group" "\
@@ -774,7 +779,7 @@ Update the .newsrc.eld file to reflect the change of nntp server." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-button-reply gnus-button-mailto gnus-msg-mail)
-;;;;;;  "gnus-msg" "gnus-msg.el" (15905 64406))
+;;;;;;  "gnus-msg" "gnus-msg.el" (15916 61433))
 ;;; Generated autoloads from gnus-msg.el
 
 (autoload (quote gnus-msg-mail) "gnus-msg" "\
@@ -949,7 +954,7 @@ Declare backend NAME with ABILITIES as a Gnus backend." nil nil)
 ;;;***
 
 ;;;### (autoloads (gnus-add-configuration) "gnus-win" "gnus-win.el"
-;;;;;;  (15895 52379))
+;;;;;;  (15916 61435))
 ;;; Generated autoloads from gnus-win.el
 
 (autoload (quote gnus-add-configuration) "gnus-win" "\
@@ -981,8 +986,8 @@ Convert HTML to plain text in the current buffer." t nil)
 ;;;;;;  message-signature-separator message-from-style message-cross-post-note-function
 ;;;;;;  message-followup-to-note message-cross-post-note message-cross-post-default
 ;;;;;;  message-archive-note message-archive-header message-mark-insert-end
-;;;;;;  message-mark-insert-begin) "message" "message.el" (15905
-;;;;;;  32042))
+;;;;;;  message-mark-insert-begin) "message" "message.el" (15916
+;;;;;;  61436))
 ;;; Generated autoloads from message.el
 
 (defvar message-mark-insert-begin "--8<---------------cut here---------------start------------->8---\n" "\
@@ -1330,7 +1335,7 @@ symbol in the alist." nil nil)
 ;;;***
 
 ;;;### (autoloads (nnfolder-generate-active-file) "nnfolder" "nnfolder.el"
-;;;;;;  (15895 52383))
+;;;;;;  (15916 61444))
 ;;; Generated autoloads from nnfolder.el
 
 (autoload (quote nnfolder-generate-active-file) "nnfolder" "\
@@ -1368,7 +1373,7 @@ Create a nnshimbun group." t nil)
 ;;;***
 
 ;;;### (autoloads (nnsoup-revert-variables nnsoup-set-variables nnsoup-pack-replies)
-;;;;;;  "nnsoup" "nnsoup.el" (15895 52391))
+;;;;;;  "nnsoup" "nnsoup.el" (15916 61445))
 ;;; Generated autoloads from nnsoup.el
 
 (autoload (quote nnsoup-pack-replies) "nnsoup" "\
@@ -1485,7 +1490,7 @@ If DATE is malformed, return a time value of zeros." nil nil)
 
 ;;;### (autoloads (uudecode-decode-region uudecode-decode-region-internal
 ;;;;;;  uudecode-decode-region-external) "uudecode" "uudecode.el"
-;;;;;;  (15418 33156))
+;;;;;;  (15916 61445))
 ;;; Generated autoloads from uudecode.el
 
 (autoload (quote uudecode-decode-region-external) "uudecode" "\
